==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/all_3.js <==
var searchData=
[
  ['data',['Data',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html',1,'fsdk::ISettingsProvider::Value::Data'],['../structfsdk_1_1_fingerprint.html#a329712d37daf5ec33e3f0ce3ee65dcfc',1,'fsdk::Fingerprint::data()'],['../structfsdk_1_1_sub_image.html#a60484aef73eab8df8b2fc8c20ef5f9fe',1,'fsdk::SubImage::data()'],['../classfsdk_1_1_span.html#a3e4ae71a7349cf4290dcce8f8d342acf',1,'fsdk::Span::data()']]],
  ['datatype',['DataType',['../classfsdk_1_1_future.html#a38f572195de92595cbc6c847fb7470ec',1,'fsdk::Future::DataType()'],['../classfsdk_1_1_promise.html#a289da90b035b98d71ff87b366523d970',1,'fsdk::Promise::DataType()']]],
  ['dct_5fcenter',['DCT_CENTER',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da763dab49108298d2d502a9749e2628e9',1,'fsdk']]],
  ['dct_5fcenter_5fand_5fconfidence',['DCT_CENTER_AND_CONFIDENCE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da113aa401fd3bbad089894a3cf8fd06b6',1,'fsdk']]],
  ['dct_5fconfidence',['DCT_CONFIDENCE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da8767054041a6b3288648b7a403ca7b17',1,'fsdk']]],
  ['dct_5fsize',['DCT_SIZE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923dab87d650f70c0d623b1419a50c24ce590',1,'fsdk']]],
  ['deallocate',['deallocate',['../structfsdk_1_1_image.html#a750cb313b381b4245a1e51e34b18ae44',1,'fsdk::Image']]],
  ['declare_5fsmartptr',['DECLARE_SMARTPTR',['../group___core_group.html#gac4832e274cc0ba20ce33c3e34503a063',1,'Def.h']]],
  ['deepfakeestimation',['DeepFakeEstimation',['../structfsdk_1_1experimental_1_1_deep_fake_estimation.html',1,'fsdk::experimental']]],
  ['def_2eh',['Def.h',['../_def_8h.html',1,'']]],
  ['default',['Default',['../structfsdk_1_1_i_serializable_object.html#ac02b734576139d792a928b0a9ade7d79a6e4800456cd37d67c1cdcfecaac8afab',1,'fsdk::ISerializableObject']]],
  ['depthestimation',['DepthEstimation',['../structfsdk_1_1_depth_estimation.html',1,'fsdk']]],
  ['depthlivenessestimation',['DepthLivenessEstimation',['../structfsdk_1_1_depth_liveness_estimation.html',1,'fsdk']]],
  ['depthrange',['DepthRange',['../structfsdk_1_1_depth_range.html',1,'fsdk']]],
  ['depthrgbestimation',['DepthRGBEstimation',['../structfsdk_1_1_depth_r_g_b_estimation.html',1,'fsdk']]],
  ['desc',['Desc',['../structfsdk_1_1_i_settings_provider_1_1_desc.html',1,'fsdk::ISettingsProvider::Desc'],['../structfsdk_1_1_i_settings_provider_1_1_desc.html#ac5b3c770ae3ec11839e56ba4b5bb1270',1,'fsdk::ISettingsProvider::Desc::Desc() noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_desc.html#a5f4b610fa970c3719789a0413c9eab4a',1,'fsdk::ISettingsProvider::Desc::Desc(const char *desc) noexcept']]],
  ['descriptorbyindex',['descriptorByIndex',['../structfsdk_1_1_i_static_descriptor_storage.html#ad7b5bde8ec689c73656628920b8aebad',1,'fsdk::IStaticDescriptorStorage']]],
  ['descriptorid',['DescriptorId',['../namespacefsdk.html#a6e9de4245746d64cc78d71602c604dee',1,'fsdk']]],
  ['descriptor_20extractor',['Descriptor extractor',['../group___descriptor_processing_group.html',1,'']]],
  ['descriptortype',['DescriptorType',['../group___descriptor_processing_group.html#ga1cd2e0e27848b58fe8d39becd00d6186',1,'fsdk']]],
  ['descriptorversion',['DescriptorVersion',['../group___descriptor_processing_group.html#gaa796beff9fb761301be4e46b1a2412ab',1,'fsdk']]],
  ['detailedmasktype',['DetailedMaskType',['../group___estimator_group.html#ga12b3d18d0723cdafd86b4902241f5cb0',1,'fsdk']]],
  ['detect',['detect',['../structfsdk_1_1_i_detector.html#abc50559be5a5f781d515ff37c0569672',1,'fsdk::IDetector::detect()'],['../structfsdk_1_1_i_head_detector.html#aef9daa9cf7e224ccda2de2ddcbac324a',1,'fsdk::IHeadDetector::detect()'],['../structfsdk_1_1_i_human_detector.html#afb7a96ba28744c63b0100e2835f6f708',1,'fsdk::IHumanDetector::detect()'],['../structfsdk_1_1_i_human_face_detector.html#a18150accfae25ab2899f5b5af021fb4a',1,'fsdk::IHumanFaceDetector::detect()']]],
  ['detectasync',['detectAsync',['../structfsdk_1_1_i_detector.html#a46857380f1a9b542b99eed236d32c29c',1,'fsdk::IDetector::detectAsync()'],['../structfsdk_1_1_i_head_detector.html#ad4dc194973552728b09427f8d58df715',1,'fsdk::IHeadDetector::detectAsync()'],['../structfsdk_1_1_i_human_detector.html#a1bc618f7907929abe3a6df08dfc16a24',1,'fsdk::IHumanDetector::detectAsync()'],['../structfsdk_1_1_i_human_face_detector.html#adda253efb82ed6553c52266763cd45a4',1,'fsdk::IHumanFaceDetector::detectAsync()']]],
  ['detection',['Detection',['../structfsdk_1_1_detection.html',1,'fsdk::Detection'],['../structfsdk_1_1_detection.html#a11f6159ee525572a4d4d1ec4e976cc68',1,'fsdk::Detection::Detection() noexcept'],['../structfsdk_1_1_detection.html#a223af77155d7a4d1f2a9cf67abfb612d',1,'fsdk::Detection::Detection(FloatRect rect, float score=1.f) noexcept'],['../structfsdk_1_1_detection.html#a61cc169cc9584adda10e9670dd3db96b',1,'fsdk::Detection::Detection(FloatRect rect, int width, int height, float score=1.f) noexcept'],['../structfsdk_1_1_detection.html#a69b29a97fe418bd6eae5523fb76c8b0f',1,'fsdk::Detection::Detection(FloatRect rect, Rect imageRect, float score=1.f) noexcept']]],
  ['detectioncomparertype',['DetectionComparerType',['../group___detector_group.html#ga7d021e05a5d867ffe947ffb40aa0923d',1,'fsdk']]],
  ['detectiontype',['DetectionType',['../group___detector_group.html#ga29cb345293d30553e7af41260cede7ad',1,'fsdk']]],
  ['detectlandmarks5',['detectLandmarks5',['../structfsdk_1_1_i_face_landmarks_detector.html#acce3f8ecc301832dcf0bc7b553df836c',1,'fsdk::IFaceLandmarksDetector::detectLandmarks5(Span&lt; const Image &gt; images, Span&lt; Span&lt; const Detection &gt;&gt; detections) const noexcept=0'],['../structfsdk_1_1_i_face_landmarks_detector.html#ad269069d6b2dec6334fed4fa4c16fd0a',1,'fsdk::IFaceLandmarksDetector::detectLandmarks5(const Image &amp;image, Span&lt; const Detection &gt; detections, Span&lt; Landmarks5 &gt; landmarks) const noexcept=0']]],
  ['detectlandmarks68',['detectLandmarks68',['../structfsdk_1_1_i_face_landmarks_detector.html#aee599b458392f4b241f068dbf60cf66e',1,'fsdk::IFaceLandmarksDetector::detectLandmarks68(Span&lt; const Image &gt; images, Span&lt; Span&lt; const Detection &gt;&gt; detections) const noexcept=0'],['../structfsdk_1_1_i_face_landmarks_detector.html#a489911815922367fb1cc61291a16d489',1,'fsdk::IFaceLandmarksDetector::detectLandmarks68(const Image &amp;image, Span&lt; const Detection &gt; detections, Span&lt; Landmarks68 &gt; landmarks) const noexcept=0']]],
  ['detectlandmarksasync',['detectLandmarksAsync',['../structfsdk_1_1_i_face_landmarks_detector.html#a8d8e9cca4ba18f547f401fc55196273a',1,'fsdk::IFaceLandmarksDetector']]],
  ['detectone',['detectOne',['../structfsdk_1_1_i_detector.html#a407bdaacb3a35f11a6b41c2bdf2d3949',1,'fsdk::IDetector::detectOne()'],['../structfsdk_1_1_i_human_detector.html#a68b933f48f92ea3b1aa1986e3d8b30d8',1,'fsdk::IHumanDetector::detectOne()']]],
  ['deviceclass',['DeviceClass',['../namespacefsdk.html#a3264388e1c930c89a6679c81b63ad0be',1,'fsdk']]],
  ['dis_5finvalid',['DIS_INVALID',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a59022e450a16f091e78179a9ec8a49a2',1,'fsdk']]],
  ['dis_5funknown',['DIS_UNKNOWN',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a8cc154b216d939d047de68831567f504',1,'fsdk']]],
  ['dis_5fvalid',['DIS_VALID',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a685715eb7fdce208bfa6bae51eaa8c5f',1,'fsdk']]],
  ['disgust',['disgust',['../structfsdk_1_1_emotions_estimation.html#ab551ab9317159e6ccdcf59cc82cbe2a9',1,'fsdk::EmotionsEstimation']]],
  ['distance',['distance',['../structfsdk_1_1_matching_result.html#a51e3137806e9938aa3b70557cbf1628b',1,'fsdk::MatchingResult']]],
  ['dt_5fall',['DT_ALL',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada1be6a902d3612661d3200257c69323fa',1,'fsdk']]],
  ['dt_5fbbox',['DT_BBOX',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7adafc1e9f167d5d1be9899f6732bc6f2110',1,'fsdk']]],
  ['dt_5fface',['DT_FACE',['../group___descriptor_processing_group.html#gga1cd2e0e27848b58fe8d39becd00d6186adfd064a1bc06eda4ce5ad8cbb32ceb05',1,'fsdk']]],
  ['dt_5fhuman',['DT_HUMAN',['../group___descriptor_processing_group.html#gga1cd2e0e27848b58fe8d39becd00d6186a55aa0ee5f96f43689faa8dc86966340e',1,'fsdk']]],
  ['dt_5flandmarks5',['DT_LANDMARKS5',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada3a1cef8a2d392799c66fe948b3cee9f4',1,'fsdk']]],
  ['dt_5flandmarks68',['DT_LANDMARKS68',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada508e9b2f679d5758e9bf979610dbb1c5',1,'fsdk']]],
  ['dv_5fmin_5fface_5fdescriptor_5fversion',['DV_MIN_FACE_DESCRIPTOR_VERSION',['../group___descriptor_processing_group.html#ggaa796beff9fb761301be4e46b1a2412aba1dfe29faa054d00d13d992fdfcffaef4',1,'fsdk']]],
  ['dv_5fmin_5fhuman_5fdescriptor_5fversion',['DV_MIN_HUMAN_DESCRIPTOR_VERSION',['../group___descriptor_processing_group.html#ggaa796beff9fb761301be4e46b1a2412aba663094a3a39d591eca695b631243f71a',1,'fsdk']]],
  ['dynamicindexstate',['DynamicIndexState',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1',1,'fsdk']]],
  ['dynamicrangeestimation',['DynamicRangeEstimation',['../structfsdk_1_1_dynamic_range_estimation.html',1,'fsdk']]],
  ['dynamicrangescore',['dynamicRangeScore',['../structfsdk_1_1_dynamic_range_estimation.html#a1fb30dd4e7501df6dd9be021dcba4df9',1,'fsdk::DynamicRangeEstimation']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/all_3.js <==
var searchData=
[
  ['dark',['Dark',['../structfsdk_1_1_light_colored_clothes_estimation.html#ac9e69ae4fab2f62191098e7593862b27aa18366b217ebf811ad1886e4f4f865b2',1,'fsdk::LightColoredClothesEstimation']]],
  ['darkscore',['darkScore',['../structfsdk_1_1_light_colored_clothes_estimation.html#a3f18218c45a737e84ed3385546da9425',1,'fsdk::LightColoredClothesEstimation']]],
  ['data',['Data',['../unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html',1,'fsdk::ISettingsProvider::Value::Data'],['../structfsdk_1_1_fingerprint.html#a329712d37daf5ec33e3f0ce3ee65dcfc',1,'fsdk::Fingerprint::data()'],['../structfsdk_1_1_a_i_d.html#a67446e2e89580effa6c260dfd51592ff',1,'fsdk::AID::data()'],['../structfsdk_1_1_sub_image.html#a60484aef73eab8df8b2fc8c20ef5f9fe',1,'fsdk::SubImage::data()'],['../classfsdk_1_1_span.html#a3e4ae71a7349cf4290dcce8f8d342acf',1,'fsdk::Span::data()']]],
  ['datatype',['DataType',['../classfsdk_1_1_future.html#a38f572195de92595cbc6c847fb7470ec',1,'fsdk::Future::DataType()'],['../classfsdk_1_1_promise.html#a289da90b035b98d71ff87b366523d970',1,'fsdk::Promise::DataType()']]],
  ['dct_5fcenter',['DCT_CENTER',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da763dab49108298d2d502a9749e2628e9',1,'fsdk']]],
  ['dct_5fcenter_5fand_5fconfidence',['DCT_CENTER_AND_CONFIDENCE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da113aa401fd3bbad089894a3cf8fd06b6',1,'fsdk']]],
  ['dct_5fconfidence',['DCT_CONFIDENCE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da8767054041a6b3288648b7a403ca7b17',1,'fsdk']]],
  ['dct_5fsize',['DCT_SIZE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923dab87d650f70c0d623b1419a50c24ce590',1,'fsdk']]],
  ['deallocate',['deallocate',['../structfsdk_1_1_image.html#a750cb313b381b4245a1e51e34b18ae44',1,'fsdk::Image']]],
  ['declare_5fsmartptr',['DECLARE_SMARTPTR',['../group___core_group.html#gac4832e274cc0ba20ce33c3e34503a063',1,'Def.h']]],
  ['deepfakeestimation',['DeepFakeEstimation',['../structfsdk_1_1experimental_1_1_deep_fake_estimation.html',1,'fsdk::experimental']]],
  ['def_2eh',['Def.h',['../_def_8h.html',1,'']]],
  ['default',['Default',['../structfsdk_1_1_i_serializable_object.html#ac02b734576139d792a928b0a9ade7d79a6e4800456cd37d67c1cdcfecaac8afab',1,'fsdk::ISerializableObject']]],
  ['depthlivenessestimation',['DepthLivenessEstimation',['../structfsdk_1_1_depth_liveness_estimation.html',1,'fsdk']]],
  ['desc',['Desc',['../structfsdk_1_1_i_settings_provider_1_1_desc.html',1,'fsdk::ISettingsProvider::Desc'],['../structfsdk_1_1_i_settings_provider_1_1_desc.html#ac5b3c770ae3ec11839e56ba4b5bb1270',1,'fsdk::ISettingsProvider::Desc::Desc() noexcept'],['../structfsdk_1_1_i_settings_provider_1_1_desc.html#a5f4b610fa970c3719789a0413c9eab4a',1,'fsdk::ISettingsProvider::Desc::Desc(const char *desc) noexcept']]],
  ['descriptorbyindex',['descriptorByIndex',['../structfsdk_1_1_i_static_descriptor_storage.html#ad7b5bde8ec689c73656628920b8aebad',1,'fsdk::IStaticDescriptorStorage']]],
  ['descriptorid',['DescriptorId',['../namespacefsdk.html#a6e9de4245746d64cc78d71602c604dee',1,'fsdk']]],
  ['descriptor_20extractor',['Descriptor extractor',['../group___descriptor_processing_group.html',1,'']]],
  ['descriptortype',['DescriptorType',['../group___descriptor_processing_group.html#ga1cd2e0e27848b58fe8d39becd00d6186',1,'fsdk']]],
  ['descriptorversion',['DescriptorVersion',['../group___descriptor_processing_group.html#gaa796beff9fb761301be4e46b1a2412ab',1,'fsdk']]],
  ['detailedmasktype',['DetailedMaskType',['../group___estimator_group.html#ga12b3d18d0723cdafd86b4902241f5cb0',1,'fsdk']]],
  ['detect',['detect',['../structfsdk_1_1_i_detector.html#abc50559be5a5f781d515ff37c0569672',1,'fsdk::IDetector::detect()'],['../structfsdk_1_1_i_head_detector.html#aef9daa9cf7e224ccda2de2ddcbac324a',1,'fsdk::IHeadDetector::detect()'],['../structfsdk_1_1_i_human_detector.html#afb7a96ba28744c63b0100e2835f6f708',1,'fsdk::IHumanDetector::detect()'],['../structfsdk_1_1_i_human_face_detector.html#a18150accfae25ab2899f5b5af021fb4a',1,'fsdk::IHumanFaceDetector::detect()']]],
  ['detectasync',['detectAsync',['../structfsdk_1_1_i_detector.html#a46857380f1a9b542b99eed236d32c29c',1,'fsdk::IDetector::detectAsync()'],['../structfsdk_1_1_i_head_detector.html#ad4dc194973552728b09427f8d58df715',1,'fsdk::IHeadDetector::detectAsync()'],['../structfsdk_1_1_i_human_detector.html#a1bc618f7907929abe3a6df08dfc16a24',1,'fsdk::IHumanDetector::detectAsync()'],['../structfsdk_1_1_i_human_face_detector.html#adda253efb82ed6553c52266763cd45a4',1,'fsdk::IHumanFaceDetector::detectAsync()']]],
  ['detection',['Detection',['../structfsdk_1_1_detection.html',1,'fsdk::Detection'],['../structfsdk_1_1_detection.html#a11f6159ee525572a4d4d1ec4e976cc68',1,'fsdk::Detection::Detection() noexcept'],['../structfsdk_1_1_detection.html#a223af77155d7a4d1f2a9cf67abfb612d',1,'fsdk::Detection::Detection(FloatRect rect, float score=1.f) noexcept'],['../structfsdk_1_1_detection.html#a61cc169cc9584adda10e9670dd3db96b',1,'fsdk::Detection::Detection(FloatRect rect, int width, int height, float score=1.f) noexcept'],['../structfsdk_1_1_detection.html#a69b29a97fe418bd6eae5523fb76c8b0f',1,'fsdk::Detection::Detection(FloatRect rect, Rect imageRect, float score=1.f) noexcept']]],
  ['detectioncomparertype',['DetectionComparerType',['../group___detector_group.html#ga7d021e05a5d867ffe947ffb40aa0923d',1,'fsdk']]],
  ['detectiontype',['DetectionType',['../group___detector_group.html#ga29cb345293d30553e7af41260cede7ad',1,'fsdk']]],
  ['detectlandmarks5',['detectLandmarks5',['../structfsdk_1_1_i_face_landmarks_detector.html#acce3f8ecc301832dcf0bc7b553df836c',1,'fsdk::IFaceLandmarksDetector::detectLandmarks5(Span&lt; const Image &gt; images, Span&lt; Span&lt; const Detection &gt;&gt; detections) const noexcept=0'],['../structfsdk_1_1_i_face_landmarks_detector.html#ad269069d6b2dec6334fed4fa4c16fd0a',1,'fsdk::IFaceLandmarksDetector::detectLandmarks5(const Image &amp;image, Span&lt; const Detection &gt; detections, Span&lt; Landmarks5 &gt; landmarks) const noexcept=0']]],
  ['detectlandmarks68',['detectLandmarks68',['../structfsdk_1_1_i_face_landmarks_detector.html#aee599b458392f4b241f068dbf60cf66e',1,'fsdk::IFaceLandmarksDetector::detectLandmarks68(Span&lt; const Image &gt; images, Span&lt; Span&lt; const Detection &gt;&gt; detections) const noexcept=0'],['../structfsdk_1_1_i_face_landmarks_detector.html#a489911815922367fb1cc61291a16d489',1,'fsdk::IFaceLandmarksDetector::detectLandmarks68(const Image &amp;image, Span&lt; const Detection &gt; detections, Span&lt; Landmarks68 &gt; landmarks) const noexcept=0']]],
  ['detectlandmarksasync',['detectLandmarksAsync',['../structfsdk_1_1_i_face_landmarks_detector.html#a8d8e9cca4ba18f547f401fc55196273a',1,'fsdk::IFaceLandmarksDetector']]],
  ['detectone',['detectOne',['../structfsdk_1_1_i_detector.html#a407bdaacb3a35f11a6b41c2bdf2d3949',1,'fsdk::IDetector::detectOne()'],['../structfsdk_1_1_i_human_detector.html#a68b933f48f92ea3b1aa1986e3d8b30d8',1,'fsdk::IHumanDetector::detectOne()']]],
  ['deviceclass',['DeviceClass',['../namespacefsdk.html#a3264388e1c930c89a6679c81b63ad0be',1,'fsdk']]],
  ['dis_5finvalid',['DIS_INVALID',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a59022e450a16f091e78179a9ec8a49a2',1,'fsdk']]],
  ['dis_5funknown',['DIS_UNKNOWN',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a8cc154b216d939d047de68831567f504',1,'fsdk']]],
  ['dis_5fvalid',['DIS_VALID',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a685715eb7fdce208bfa6bae51eaa8c5f',1,'fsdk']]],
  ['disgust',['disgust',['../structfsdk_1_1_emotions_estimation.html#ab551ab9317159e6ccdcf59cc82cbe2a9',1,'fsdk::EmotionsEstimation']]],
  ['distance',['distance',['../structfsdk_1_1_matching_result.html#a51e3137806e9938aa3b70557cbf1628b',1,'fsdk::MatchingResult']]],
  ['drawn',['Drawn',['../structfsdk_1_1_photorealistic_face_estimation.html#a02d580080a36d0718bb4b1bb78178efbac4816e491f1e2cf4b8c26d844861d8fe',1,'fsdk::PhotorealisticFaceEstimation']]],
  ['dt_5fall',['DT_ALL',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada1be6a902d3612661d3200257c69323fa',1,'fsdk']]],
  ['dt_5fbbox',['DT_BBOX',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7adafc1e9f167d5d1be9899f6732bc6f2110',1,'fsdk']]],
  ['dt_5fface',['DT_FACE',['../group___descriptor_processing_group.html#gga1cd2e0e27848b58fe8d39becd00d6186adfd064a1bc06eda4ce5ad8cbb32ceb05',1,'fsdk']]],
  ['dt_5fhuman',['DT_HUMAN',['../group___descriptor_processing_group.html#gga1cd2e0e27848b58fe8d39becd00d6186a55aa0ee5f96f43689faa8dc86966340e',1,'fsdk']]],
  ['dt_5flandmarks5',['DT_LANDMARKS5',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada3a1cef8a2d392799c66fe948b3cee9f4',1,'fsdk']]],
  ['dt_5flandmarks68',['DT_LANDMARKS68',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada508e9b2f679d5758e9bf979610dbb1c5',1,'fsdk']]],
  ['dutyuniformestimation',['DutyUniformEstimation',['../structfsdk_1_1_duty_uniform_estimation.html',1,'fsdk']]],
  ['dv_5fmin_5fface_5fdescriptor_5fversion',['DV_MIN_FACE_DESCRIPTOR_VERSION',['../group___descriptor_processing_group.html#ggaa796beff9fb761301be4e46b1a2412aba1dfe29faa054d00d13d992fdfcffaef4',1,'fsdk']]],
  ['dv_5fmin_5fhuman_5fdescriptor_5fversion',['DV_MIN_HUMAN_DESCRIPTOR_VERSION',['../group___descriptor_processing_group.html#ggaa796beff9fb761301be4e46b1a2412aba663094a3a39d591eca695b631243f71a',1,'fsdk']]],
  ['dynamicindexstate',['DynamicIndexState',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1',1,'fsdk']]],
  ['dynamicrangeestimation',['DynamicRangeEstimation',['../structfsdk_1_1_dynamic_range_estimation.html',1,'fsdk']]],
  ['dynamicrangescore',['dynamicRangeScore',['../structfsdk_1_1_dynamic_range_estimation.html#a1fb30dd4e7501df6dd9be021dcba4df9',1,'fsdk::DynamicRangeEstimation']]]
];
